<?php

namespace AppBundle\Controller;

use Sensio\Bundle\FrameworkExtraBundle\Configuration\Route;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Method;
use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpFoundation\File\UploadedFile;
use Symfony\Component\HttpFoundation\JsonResponse;
use AppBundle\Model\SubsFormat\FormatSRT;
use AppBundle\Model\SubsFormat\Subtitle as Subtitle;
use AppBundle\Model\SubsFormat\FormatFCP7;
use AppBundle\Entity\FCP7Param as FCP7Param;
use AppBundle\Model\SubsFormat\FormatFCPXv1_1 as fcpxmlv11;
use AppBundle\SubsFormat\utils\UtilsSubsFormat as Utils;



class ExportSubsController extends Controller
{

	/**
    * @Route("/show/subs/{subsFormat}", 
    *       name="showSubsForm", 
    *       options={"expose"=true}, 
    *       condition="request.isXmlHttpRequest()")
    *     
    */
    public function showSubsFormAction($subsFormat)
    {

    	$template = $this->render('format/'.$subsFormat.'Form.html.twig', array('paramId' => 4))->getContent();

        return  new JsonResponse($template);    

    }


    /**
    * @Route("/export/subs/{subsFormat}", name="exportSubsForm")
    * @Method ({"POST"})
    */
    public function exportSubsAction(Request $request, $subsFormat)
    {

        if ($request->getMethod() == 'POST') {

            //DATA RECOVERING
            $data = $request->request->all();
        

            //SUBTITLE PARAMETERS
            $Originalfilename = $data['filename'];
            $charset = $data['originalCharset'];
            $originalFrameRate = $data['originalFrameRate'];   


            // SUBTITLE LIST
            $subslength = count($data['subtitle']['id']);
            for ($x = 0; $x < $subslength; $x++) {
                $id = $data['subtitle']['id'][$x];
                $tcIn = $data['subtitle']['tcIn'][$x];
                $tcOut = $data['subtitle']['tcOut'][$x];


                if ($data['exportColumnSubs'] == 'subtitle'){
                    $text = $data['subtitle']['text'][$x];
                } 
                elseif ($data['exportColumnSubs'] == 'translation') {
                    $text = $data['subtitle']['textTrans'][$x];
                }

                if (isset($data['subtitle']['italic'][($data['subtitle']['id'][$x])])) {
                    $italic = true;
                } else {
                    $italic = false;
                }

                $subtitlesList[] = new Subtitle($id, $tcIn, $tcOut, $text, $italic);

            }


            switch ($subsFormat) {
                case 'srt':
                    // CREATE A NEW FILE
                    $targetFrameRate = $data['targetFrameRate'];
                    $file = new FormatSRT();    
                    $filename = $file->createNewFile($subtitlesList, $originalFrameRate, $targetFrameRate);

                    // SET HEADERS
                    $response = new Response();
                    $response->headers->set('Cache-Control', 'private');
                    $response->headers->set('Content-type', mime_content_type($filename));
                    $response->headers->set('Content-Disposition', 'attachment; filename="'.basename($filename).'";');
                    $response->headers->set('Content-length', filesize($filename));

                    // SEND HEADERS
                    $response->sendHeaders();
                    $response->setContent(file_get_contents($filename));
                    return $response;

                    break;
                

                case 'fcp7': 
                
                    //RECOVER VIDEO PARAMETERS

                    $refFile = $request->files->get('refFile');
                   
                    if (null === $refFile) {
                        $targetFrameRate   = $data['targetFrameRate']; 
                        if (isset($data['anamorphic'])) {
                            $anamorphic = 'TRUE';
                        } else {
                            $anamorphic = 'FALSE';
                        }
                        list($resWidth, $resHeight) = explode('x', $data['videoResolution']);
                    }

                    
                    //RECOVER XML STYLE PARAMETERS

                    $param = new FCP7Param();

                    // TEXT PARAM
                    if (trim($data["typoCustom"]) == "") {
                        $param->setTypo($data['typo']);
                    } else{
                        $param->setTypo($data['typoCustom']);
                    }
                    $param->setTextSize($data["textSize"]);
                    $param->setTextStyle($data["textStyle"]);
                    $param->setAlignment($data["alignment"]);
                    $param->setTracking($data["tracking"]);
                    $param->setTextLeading($data["textLeading"]);
                    $param->setAspect($data["aspect"]);
                    $param->setTextOpacity($data["textOpacity"]);

                    if ($data['sameLine'] == "true"){
                        $param->setSameLine(true);
                        $param->setCenterXone($data['centerXtwo']);
                        $param->setCenterYone($data['centerYtwo']);
                        $param->setCenterXtwo($data['centerXtwo']);
                        $param->setCenterYtwo($data['centerYtwo']);
                    } else {
                        $param->setSameLine(false);
                        $param->setCenterXone($data['centerXone']);
                        $param->setCenterYone($data['centerYone']);
                        $param->setCenterXtwo($data['centerXtwo']);
                        $param->setCenterYtwo($data['centerYtwo']);

                    }
                    $param->setTextColor($this->hexToRgb($data["textColor"]));
                    $param->setColorAlpha($data["colorAlpha"]);

                    // OUTLINE PARAM
                    $param->setLineWidth($data["lineWidth"]);
                    $param->setLineSoftness($data["lineSoftness"]);
                    $param->setOutColor($this->hexToRgb($data["outColor"]));
                    $param->setOutColorAlpha($data["outColorAlpha"]);

                    //BACKGROUND PARAM
                    $param->setXScale($data["xScale"]);
                    $param->setYScale($data["yScale"]);
                    $param->setXOffset($data["xOffset"]);
                    $param->setYOffset($data["yOffset"]);
                    $param->setBackSoft($data["backSoft"]);
                    $param->setBackOpacity($data["backOpacity"]);
                    $param->setBackColor($this->hexToRgb($data["backColor"]));
                    $param->setBackColorAlpha($data["backColorAlpha"]);

                    //OTHERS
                    $param->setKern($data['kern']);
                    $param->setCrop($data['crop']);

                    //CHECK REFERENCE FILE

                    if (null === $refFile) {
                         $newFile = new FormatFCP7();
                         $newFile->createNewFile(null, $subtitlesList, $param, $originalFrameRate, $targetFrameRate, $resWidth, $resHeight, $anamorphic);
                    } else {
                        $newFile = new FormatFCP7();
                        $newFile->createNewFile($refFile, $subtitlesList, $param, $originalFrameRate, null, null, null, null);
                    }
                    
                    break;

                case 'fcpxv11':
                    
                    # code...
                    break;
            }
        }
    }

   public function hexToRgb($hex) {
       $hex = str_replace("#", "", $hex);

       if(strlen($hex) == 3) {
          $r = hexdec(substr($hex,0,1).substr($hex,0,1));
          $g = hexdec(substr($hex,1,1).substr($hex,1,1));
          $b = hexdec(substr($hex,2,1).substr($hex,2,1));
       } else {
          $r = hexdec(substr($hex,0,2));
          $g = hexdec(substr($hex,2,2));
          $b = hexdec(substr($hex,4,2));
       }
       $rgb = array($r, $g, $b);
       //return implode(",", $rgb); // returns the rgb values separated by commas
       return $rgb; // returns an array with the rgb values
    }



}
