<?php

namespace AppBundle\Controller;

use Sensio\Bundle\FrameworkExtraBundle\Configuration\Route;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Method;
use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\Form\Extension\Core\Type\FileType;
use Symfony\Component\Form\Extension\Core\Type\TextType;
use Symfony\Component\Form\Extension\Core\Type\SubmitType;
use Symfony\Component\Form\Extension\Core\Type\EmailType;
use Symfony\Component\Form\Extension\Core\Type\TextareaType;
use Symfony\Component\Form\Extension\Core\Type\ChoiceType;
use Symfony\Component\Form\ChoiceList\ArrayChoiceList;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpFoundation\File\UploadedFile;
use Symfony\Component\Validator\Constraints\NotBlank;
use Symfony\Component\Validator\Constraints\NotEqualTo;
use AppBundle\Model\SubsFormat\FormatSRT;
use AppBundle\Model\SubsFormat\FormatFCP7;
use AppBundle\Model\SubsFormat\FormatFCPXv1_1;
use AppBundle\Model\SubsFormat\FormatFCPXv1_3;
use AppBundle\Model\SubsFormat\utils\UtilsSubsFormat as Utils;




class IndexController extends Controller
{



    /**
     * @Route("/about", name="about")
     */
    public function aboutAction(Request $request)
    {
        return $this->render('about.html.twig');
    }

    /**
     * @Route("/", name="upload")
     */
    public function uploadAction(Request $request)
    {


        //CREATE UPLOAD FORM

        $form = $this->createFormBuilder()
            ->add('subtitleFile', FileType::class, array(
                    'constraints' => new NotBlank,
                    'label' => 'Choose a Subtitle File (.srt, .xml, .fcpxml)'
                    ))
            ->add('charset', ChoiceType::class, array(
                'choices' => array(
                    'ISO-8859' => array(
                            'ISO-8859-1 (Western Europe)' => 'ISO-8859-1',
                            'ISO-8859-2 (Western and Central Europe)' => 'ISO-8859-2',
                            'ISO-8859-3 (Western and South Europe)' => 'ISO-8859-3',
                            'ISO-8859-4 (Western Europe and Baltic)' => 'ISO-8859-4',
                            'ISO-8859-5 (Cirylic)' => 'ISO-8859-5',
                            'ISO-8859-6 (Arab)' => 'ISO-8859-6',
                            'ISO-8859-7 (Greek)' => 'ISO-8859-7',
                            'ISO-8859-8 (Hebrew)' => 'ISO-8859-8',
                            'ISO-8859-9 (Western Europe with turkish char)' => 'ISO-8859-9',
                            'ISO-8859-10 (Western Europe with nordic char)' => 'ISO-8859-10',
                            'ISO-8859-11 (Tailand)' => 'ISO-8859-11',
                            'ISO-8859-13 (Baltic and Polish)' => 'ISO-8859-13',
                            'ISO-8859-14 (Celtic: gaélico irlandés, escocés, welsh)' => 'ISO-8859-14',
                            'ISO-8859-15 (Europa occidental+€)' => 'ISO-8859-15',
                            'ISO-8859-16 (Centroeuropeos)' => 'ISO-8859-16',
                    ),
                    'Windows' => array(
                            'Windows-1250 (Central Europe with Latin hyphen)' => 'Windows-1250',
                            'Windows-1251 (Cirylic)' => 'Windows-1251',
                            'Windows-1252 (Western Europe)' => 'Windows-1252',
                            'Windows-1253 (Greek)' => 'Windows-1253',
                            'Windows-1254 (Turco)' => 'Windows-1254',
                            'Windows-1255 (Hebrew)' => 'Windows-1255',
                            'Windows-1256 (Arab)' => 'Windows-1256',
                            'Windows-1257 (Baltic)' => 'Windows-1257',
                            'Windows-1258 (Vietnam)' => 'Windows-1258',
                    ),
                    'Unicode' => array(
                            'UTF-8' => 'utf-8',
                            'UTF-16' => 'UTF-16',
                            'UTF-16BE' => 'UTF-16BE',
                            'UTF-16LE' => 'UTF-16LE',
                            'UTF-32' => 'UTF-32',
                            'UTF-32BE' => 'UTF-32BE',
                            'UTF-32LE' => 'UTF-32LE',
                    ),
                    'CP' => array(
                            'CP437' => 'CP437',
                            'CP737' => 'CP737',
                            'CP850' => 'CP850',
                            'CP852' => 'CP852',
                            'CP855' => 'CP855',
                            'CP857' => 'CP857',
                            'CP858' => 'CP858',
                            'CP860' => 'CP860',
                            'CP861' => 'CP861',
                            'CP863' => 'CP863',
                            'CP865' => 'CP865',
                            'CP866' => 'CP866',
                            'CP869' => 'CP869',
                            'CP930' => 'CP930',
                    ),


                 ),
                 'choices_as_values' => true,
                 'constraints' => new NotEqualTo('0'),
                 ))

             ->add('frameRate', ChoiceType::class, array(
                'choices' => array(
                    '23.98' => '23.98',
                    '24' => '24',
                    '25' => '25',
                    '29.97' => '29.97',
                    '30' => '30',
                    '48' => '48',
                    '50' => '50',
                    '59.94' => '59.94',
                    '60' => '60',
                    ),
                'data' => '24',
                'choices_as_values' => true,
                'constraints' => new NotEqualTo('0'),
            ))
            ->add('send', SubmitType::class)
            ->getForm();

        $form->handleRequest($request);

                   
        if ($form->isSubmitted() && $form->isValid()) {
             
           
            $file = $form['subtitleFile']->getData();
            $name = $file->getClientOriginalName();
            $extension = $file->getClientOriginalExtension();

            switch ($extension) {

                case 'srt':

                    $charset = $form['charset']->getData();
                    $frameRate = $form['frameRate']->getData();

                    $srt = new FormatSRT($file);
                    $srt->setName($name);
                    $srt->setExtension($extension);
                    $srt->setCharset($charset);
                    $srt->setFrameRate($frameRate);
                    $subtitols = $srt->getSubtitlesList();

                    return $this->render('subsInfo/srtInfo.html.twig', array('subtitles' => $subtitols, 'fileName' => $srt->getName(), 'charset' => $srt->getCharset(), 'extension'=>$srt->getExtension(), 'frameRate'=>$srt->getFrameRate(), 'title' => 'Homepage'
                    ));
                    
                case 'xml':

                    $xml = new FormatFCP7($file);
                    $xml->setName($name);
                    $xml->setExtension($extension);
                    $xml->setVersion();
                    $xml->setFrameRate();
                    $xml->setCharset();
                    $subtitols = $xml->getSubtitlesList(); 
                    $videoParam = $xml->getParamList();
                    
                    return $this->render('subsInfo/fcpInfo.html.twig', array('subtitles' => $subtitols, 'fileName' => $xml->getName(), 'charset' => $xml->getCharset(), 'extension'=>$xml->getExtension(), 'version'=>$xml->getVersion(), 'frameRate'=>$xml->getFrameRate(),'videoParam'=>$videoParam, 
                    ));
                    
                case 'fcpxml':

                    $version = Utils::getVersionFile($file);
                    
                    if ($version == '1' || $version == '1.0' || $version == '1.1' || $version == '1.2') 
                    {
                        $fcpxml = new FormatFCPXv1_1($file);
                    }

                    if ($version == '1.3' || $version == '1.4' || $version == '1.5' || $version == '1.6') 
                    {
                        $fcpxml = new FormatFCPXv1_3($file);
                    }

                    $fcpxml->setName($name);
                    $fcpxml->setExtension($extension);
                    $fcpxml->setCharset('utf-8');
                    $fcpxml->setFrameRate();
                    $fcpxml->setVersion();
                    $subtitols = $fcpxml->getSubtitlesList(); 
                    $videoParam = $fcpxml->getParamList();
                    
                    return $this->render('subsInfo/fcpXInfo.html.twig', array('subtitles' => $subtitols, 'fileName' => $fcpxml->getName(), 'charset' => $fcpxml->getCharset(), 'extension'=>$fcpxml->getExtension(),'version'=>$fcpxml->getVersion(), 'frameRate'=>$fcpxml->getFrameRate(),'videoParam'=>$videoParam,
                    ));
                    

                default:
                    return $this->render('upLoadFile.html.twig', array(
                    'form' => $form->createView(),
                 ));
            }

            


         } else {
             return $this->render('upLoadFile.html.twig', array(
            'form' => $form->createView()
            ));
        }

        return $this->render('upLoadFile.html.twig', array(
                'form' => $form->createView(),
        ));


    }



}
