<?php
namespace AppBundle\Model\SubsFormat;

/**
 * srtFormat.class.php
 *
 * Class to work with .srt files.
 *
 * @package PHP srtFormat;
 * @category Subtitles
 * @author Víctor Hernández Torner
 * @copyright 2017 Víctor Hernández Torner
 * @license https://opensource.org/licenses/GPL-3.0 GNU General Public License 3.0
 * @version 1.0
 * 
 */

/**
 * Class xmlFormat
 *
 * @package SubsFormat
 *
 */


abstract class Format {

    protected $file;
    protected $name;
    protected $extension;
    protected $charset;
    protected $frameRate;
    protected $subtitlesList;


    public function __construct($file = null) {
        $this->file = $file;
        if ($file !== null) $this->loadFile($this->file);
    }


    abstract public function loadFile();
    abstract public function getSubtitlesList();
    abstract public function createNewFile();



    //SETTERS & GETTERS

    public function getFile(){
        return $this->file;
    }

    public function setFile($file){
        $this->file = $file;
    }

    public function getName(){
        return $this->name;
    }

    public function setName($name){
        $this->name = $name;
    }

    public function getExtension(){
        return $this->extension;
    }

    public function setExtension($extension){
        $this->extension = $extension;
    }


    public function setSubtitlesList($subtitlesList){
        $this->subtitlesList = $subtitlesList;
    }

    public function getCharset(){
        return $this->charset;
    }

    public function setCharset($charset){
        $this->charset = $charset;
    }

     public function getFrameRate(){
        return $this->frameRate;
    }

    public function setFrameRate($frameRate){
        $this->frameRate = $frameRate;
    }

    protected  function framesToTc($tc, $frameRate) {

        $secondsTotal = floor($tc/$frameRate);
        $frames = $tc % $frameRate;

        $hours = floor($secondsTotal / 3600);
        $mins = floor($secondsTotal / 60 % 60);
        $secs = floor($secondsTotal % 60);

        $tcString = str_pad($hours, 2, "0", STR_PAD_LEFT).":".str_pad($mins, 2, "0", STR_PAD_LEFT).":".str_pad($secs, 2, "0", STR_PAD_LEFT).":".str_pad($frames, 2, "0", STR_PAD_LEFT);

        return $tcString;
    }

    protected function tcToFrames($tc, $frameRate) {

        $hores = substr($tc, 0, 2) * 3600 * $frameRate;
        $minuts = substr($tc, 3, 2) * 60 * $frameRate;
        $segons = substr($tc, 6, 2) * $frameRate;
        $frames = substr($tc, 9, 2);
        $framesTotals = $hores + $minuts + $segons + $frames;
        return $framesTotals;
    }


    protected function changeFrameRate($tc, $originalFr, $targetFr) {
        $frames =  $this->tcToFrames($tc, $originalFr);
        $newTc = $this->framesToTc($frames, $targetFr);
        return $newTc;
    }

}