<?php
namespace AppBundle\Model\SubsFormat;

use AppBundle\Model\SubsFormat\Format;
use Symfony\Component\HttpFoundation\File\UploadedFile;
use Symfony\Component\HttpFoundation\Response;
use AppBundle\Model\SubsFormat\Subtitle as Subtitle;
use AppBundle\Entity\FCP7Param as FCP7Param;
use AppBundle\SubsFormat\utils\UtilsSubsFormat as Utils;


class FormatFCP7 extends Format
{

    protected $xml;
    protected $xmlSimple;

    // Video Parameters
    protected $version;
    protected $widthRes;
    protected $heightRes;
    protected $resolution;
    protected $seqName;
    protected $seqDuration;
    protected $videoFormat;
    protected $anamorphic;
    protected $pixelAspect;
    protected $uuid;


    public function __construct($file=null) {
        parent::__construct($file);
        if ($file !== null) $this->loadFile($this->file);
    }
   
    public function loadFile(){
        // Open File
        $this->xmlSimple = simplexml_load_file($this->file);
        $this->xml = new \DomDocument();
        $this->xml->loadXML($this->xmlSimple->asXML());
    }

    
    public function getSubtitlesList()
    {


        $trackNumbers = $this->xmlSimple->sequence->media->video->track;
        $count = 1;
        foreach ($trackNumbers as $track) {
            foreach ($track->generatoritem as $generatoritem) {
                if ($generatoritem->effect->effectid == 'Outline Text' || $generatoritem->effect->effectid == 'Text'){

                    $id = $count;       
                    $tcIn = $this->framesToTc($generatoritem->start, $this->frameRate);
                    $tcOut = $this->framesToTc($generatoritem->end, $this->frameRate);


                    if (strtolower($this->charset) != 'utf-8') {
                        $text = iconv($this->charset, 'utf-8//IGNORE', trim($generatoritem->effect->parameter[1]->value));
                    } else {
                        $text = trim($generatoritem->effect->parameter[1]->value);
                    }


                    if ($generatoritem->effect->parameter[3]->value == '3'){
                         $italic = true;
                    } else {
                        $italic = false;
                    }

                    $this->subtitlesList[] = new Subtitle($id, $tcIn, $tcOut, $text, $italic);
                    $count += 1;
                }
            }
        }

        return $this->subtitlesList;
    }
    

    public function getParamList()
    {

        // GET ALL PARAMETERS FROM THE FILE
        $sampleTag = $this->xml->getElementsByTagName('video')->item(0)->getElementsByTagName('format')->item(0)->getElementsByTagName('samplecharacteristics');
        $sequenceTag = $this->xml->getElementsByTagName('sequence');
        $this->seqName = $sequenceTag->item(0)->getElementsByTagName('name')->item(0)->nodeValue;
        $this->widthRes = $sampleTag->item(0)->getElementsByTagName('width')->item(0)->nodeValue;
        $this->heightRes = $sampleTag->item(0)->getElementsByTagName('height')->item(0)->nodeValue;
        $this->resolution =  $this->widthRes.'x'.$this->heightRes;
        $this->videoFormat = $sampleTag->item(0)->getElementsByTagName('codec')->item(0)->getElementsByTagName('name')->item(0)->nodeValue;
        $this->pixelAspect = $sampleTag->item(0)->getElementsByTagName('pixelaspectratio')->item(0)->nodeValue;
        $this->anamorphic = $sampleTag->item(0)->getElementsByTagName('anamorphic')->item(0)->nodeValue;
        $duration = $sequenceTag->item(0)->getElementsByTagName('duration')->item(0)->nodeValue;
        $this->seqDuration = $this->framesToTc($duration, $this->frameRate);
        if (isset($sequenceTag->item(0)->getElementsByTagName('uuid')->item(0)->nodeValue)) {
             $this->uuid = $sequenceTag->item(0)->getElementsByTagName('uuid')->item(0)->nodeValue;
        } else {
             $this->uuid = 'This property no exists';
        }
    
    
        $videoParamList = array(
            'seqName' => $this->seqName,
            'seqDuration' => $this->seqDuration,
            'resolution' => $this->resolution,
            'videoFormat' => $this->videoFormat,
            'anamorphic' => $this->anamorphic,
            'pixelAspectRatio' => $this->pixelAspect,
            'uuid'=> $this->uuid,
        ); 

        return $videoParamList;
       
    }

    public function createNewFile($refFile = null, $subtitlesList=null, $param=null, $originalFrameRate=null, $targetFrameRate=null, $resWidth=null, $resHeight=null, $anamorphic=null) 
    {

        //CHECKING IF EXIST REFERENCE FILE
        if (null !== $refFile) {
            $xmlSimple = simplexml_load_file($refFile);
            $xml = new \DomDocument();
            $xml->loadXML($xmlSimple->asXML());

            $sampleTag = $xml->getElementsByTagName('video')->item(0)->getElementsByTagName('format')->item(0)->getElementsByTagName('samplecharacteristics');


            $resWidth = $sampleTag->item(0)->getElementsByTagName('width')->item(0)->nodeValue;
            $resHeight = $sampleTag->item(0)->getElementsByTagName('height')->item(0)->nodeValue;
            $anamorphic = $sampleTag->item(0)->getElementsByTagName('anamorphic')->item(0)->nodeValue;
            $targetFrameRate = $xml->getElementsByTagName('timecode')->item(0)->getElementsByTagName('timebase')->item(0)->nodeValue;
        }


        //CHANGE FRAME RATE IF THEY ARE DIFFERENT
        if (!($targetFrameRate == 'thesame' || $targetFrameRate == $originalFrameRate)) {
            $frameRate = $targetFrameRate;

            foreach ($subtitlesList as $line) {
                $newTcIn = $this->changeFrameRate($line->getTcIn(), $originalFrameRate,  $targetFrameRate);
                $newTcOut = $this->changeFrameRate($line->getTcOut(), $originalFrameRate,  $targetFrameRate);
                $line->setTcIn($newTcIn);
                $line->setTcOut($newTcOut);
            }
        } else {
            $frameRate = $originalFrameRate;
        }


        if (null !== $refFile) {
            $path = $refFile;    
        } else {
            $path = __DIR__.'/../../../../web/files/fcp7_timeline_buit_hd.xml';
        }
        

        // CREATE NEW XML FILE
        $file = new \DOMDocument();
        $file -> formatOutput = TRUE;
        $file -> preserveWhiteSpace = FALSE;
        $file -> load($path);
        $file -> formatOutput = TRUE;

        //WRITTING RESOLUTION INFO IN THE FILE
        $sampleTag = $file->getElementsByTagName('video')->item(0)->getElementsByTagName('format')->item(0)->getElementsByTagName('samplecharacteristics');

        $sampleTag->item(0)->getElementsByTagName('width')->item(0)->nodeValue = $resWidth;
        $sampleTag->item(0)->getElementsByTagName('height')->item(0)->nodeValue = $resHeight;
        $sampleTag->item(0)->getElementsByTagName('anamorphic')->item(0)->nodeValue = $anamorphic;
         
        // CREATING THE MAIN NODE TRACK    
        $track = $file->createElement("track"); 
        $newTrack = $file->getElementsByTagName('video')->item(0)->appendChild($track);

         // FOR EACH SUBTITLE, WE CREATE A NEW GENERATOR ITEM NODE  
        foreach ($subtitlesList as $sub) {    

            $generatoritem = $file->createElement("generatoritem");
            $generatoritem->setAttribute("id", "Outline Text");
            $newGeneratoritem = $track->appendChild($generatoritem);
            
            
            $name = $file->createElement("name", "Outline Text");
            $newName = $generatoritem->appendChild($name);

            $duration = $file->createElement("duration", "3000");
            $newDuration = $generatoritem->appendChild($duration);
            
            $rate = $file->createElement("rate");
            $newRate = $generatoritem->appendChild($rate);
            
                $ntscTag = $file->createElement("ntsc", 'FALSE');
                $newNtsc = $rate->appendChild($ntscTag);
            
                $timebase = $file->createElement("timebase", $frameRate);
                $newTimebase = $rate->appendChild($timebase);
            
            $in = $file->createElement("in", "1375" );
            $newIn = $generatoritem->appendChild($in);
            
            $out = $file->createElement("out", "1625" );
            $newOut = $generatoritem->appendChild($out);
            


            $start = $file->createElement("start", $this->tcToFrames($sub->getTcIn(), $frameRate));
            $newStart = $generatoritem->appendChild($start);
            
            $end = $file->createElement("end", $this->tcToFrames($sub->getTcOut(), $frameRate));
            $newEnd = $generatoritem->appendChild($end);
            
            $enabled = $file->createElement("enabled", "TRUE");
            $newEnabled = $generatoritem->appendChild($enabled);
            
            $anamorphicTag = $file->createElement("anamorphic", $anamorphic);
            $newAnamorphic = $generatoritem->appendChild($anamorphicTag);
            
            $alphatype = $file->createElement("alphatype", "black");
            $newAlphatype = $generatoritem->appendChild($alphatype);
            
            $effect = $file->createElement("effect");
            $newEffect = $generatoritem->appendChild($effect);
            
            $name2 = $file->createElement("name", "Outline Text");
            $newName2 = $effect->appendChild($name2);
            
            $effectid = $file->createElement("effectid", "Outline Text");
            $newEffectid = $effect->appendChild($effectid);
            
            $effectcategory = $file->createElement("effectcategory", "Text");
            $newEffectcategory = $effect->appendChild($effectcategory);
            
            $effecttype = $file->createElement("effecttype", "generator");
            $newEffecttype = $effect->appendChild($effecttype);
            
            $mediatype = $file->createElement("mediatype", "video");
            $newMediatype = $effect->appendChild($mediatype);

            $parameter1 = $file->createElement("parameter");
            $newParameter1 = $effect->appendChild($parameter1);
                
                $parameter1id = $file->createElement("parameterid", "part1");
                $newParameter1id = $parameter1->appendChild($parameter1id);
                
                $parameter1name = $file->createElement("name", "Text Settings");
                $newParameter1name = $parameter1->appendChild($parameter1name);
                
                $parameter1value = $file->createElement("value");
                $newParameter1value = $parameter1->appendChild($parameter1value);
            
            //Text Contingut

            
            $parameter2 = $file->createElement("parameter");
            $newParameter2 = $effect->appendChild($parameter2);

                $parameter2id = $file->createElement("parameterid", "str");
                $newParameter2id = $parameter2->appendChild($parameter2id);
                
                $parameter2name = $file->createElement("name", "Text");
                $newParameter2name = $parameter2->appendChild($parameter2name);
                
                    $parameter2value = $file->createElement("value", $sub->getText());
                    $newParameter2value = $parameter2->appendChild($parameter2value);




            //Font Tipografia
            
            $parameter3 = $file->createElement("parameter");
            $newParameter3 = $effect->appendChild($parameter3);

                $parameter3id = $file->createElement("parameterid", "font");
                $newParameter3id = $parameter3->appendChild($parameter3id);
                
                $parameter3name = $file->createElement("name", "Font");
                $newParameter3name = $parameter3->appendChild($parameter3name);
                
                $parameter3value = $file->createElement("value", $param->getTypo());
                $newParameter3value = $parameter3->appendChild($parameter3value);
            


            //Style Font
            
            $parameter4 = $file->createElement("parameter");
            $newParameter4 = $effect->appendChild($parameter4);

                $parameter4id = $file->createElement("parameterid", "style");
                $newParameter4id = $parameter4->appendChild($parameter4id);
                
                $parameter4name = $file->createElement("name", "Style");
                $newParameter4name = $parameter4->appendChild($parameter4name);
                
                $parameter4valuemin = $file->createElement("valuemin", "1");
                $newParameter4valuemin = $parameter4->appendChild($parameter4valuemin);
                
                $parameter4valuemax = $file->createElement("valuemax", "4");
                $newParameter4valuemax = $parameter4->appendChild($parameter4valuemax);
                
                $parameter4valuelist= $file->createElement("valuelist");
                $newParameter4valuelist = $parameter4->appendChild($parameter4valuelist);
                
                    $parameter4valueentry1= $file->createElement("valueentry");
                    $newParameter4valueentry1 = $parameter4valuelist->appendChild($parameter4valueentry1);

                        $parameter4valueentry1name= $file->createElement("name", "Plain");
                        $newParameter4valueentry1name = $parameter4valueentry1->appendChild($parameter4valueentry1name);
                        
                        $parameter4valueentry1value= $file->createElement("value", "1");
                        $newParameter4valueentry1value = $parameter4valueentry1->appendChild($parameter4valueentry1value);
                            

                    $parameter4valueentry2= $file->createElement("valueentry");
                    $newParameter4valueentry2 = $parameter4valuelist->appendChild($parameter4valueentry2);
                        
                        $parameter4valueentry2name= $file->createElement("name", "Bold");
                        $newParameter4valueentry2name = $parameter4valueentry2->appendChild($parameter4valueentry2name);
                        
                        $parameter4valueentry2value= $file->createElement("value", "2");
                        $newParameter4valueentry2value = $parameter4valueentry2->appendChild($parameter4valueentry2value);
                    
                    $parameter4valueentry3 = $file->createElement("valueentry");
                    $newParameter4valueentry3 = $parameter4valuelist->appendChild($parameter4valueentry3);
                    
                        $parameter4valueentry3name= $file->createElement("name", "Italic");
                        $newParameter4valueentry3name = $parameter4valueentry3->appendChild($parameter4valueentry3name);
                        
                        $parameter4valueentry3value= $file->createElement("value", "3");
                        $newParameter4valueentry3value = $parameter4valueentry3->appendChild($parameter4valueentry3value);
                    
                    $parameter4valueentry4 = $file->createElement("valueentry");
                    $newParameter4valueentry4 = $parameter4valuelist->appendChild($parameter4valueentry4);
            
                        $parameter4valueentry4name= $file->createElement("name", "Bold/Italic");
                        $newParameter4valueentry4name = $parameter4valueentry4->appendChild($parameter4valueentry4name);
                        
                        $parameter4valueentry4value= $file->createElement("value", "4");
                        $newParameter4valueentry4value = $parameter4valueentry4->appendChild($parameter4valueentry4value);

                $parameter4value = $file->createElement("value", $this->checkStyleText($param, $sub->getItalic()));
                $newParameter4value = $parameter4->appendChild($parameter4value);
                        
            
            //Alignment
            
            $parameter5 = $file->createElement("parameter");
            $newParameter5 = $effect->appendChild($parameter5);

                $parameter5id = $file->createElement("parameterid", "align");
                $newParameter5id = $parameter5->appendChild($parameter5id);
                
                $parameter5name = $file->createElement("name", "Alignment");
                $newParameter5name = $parameter5->appendChild($parameter5name);
                
                $parameter5valuemin = $file->createElement("valuemin", "1");
                $newParameter5valuemin = $parameter5->appendChild($parameter5valuemin);
                
                $parameter5valuemax = $file->createElement("valuemax", "3");
                $newParameter5valuemax = $parameter5->appendChild($parameter5valuemax);
                
                $parameter5valuelist= $file->createElement("valuelist");
                $newParameter5valuelist = $parameter5->appendChild($parameter5valuelist);
                
                    $parameter5valueentry1= $file->createElement("valueentry");
                    $newParameter5valueentry1 = $parameter5valuelist->appendChild($parameter5valueentry1);

                        $parameter5valueentry1name= $file->createElement("name", "Left");
                        $newParameter5valueentry1name = $parameter5valueentry1->appendChild($parameter5valueentry1name);
                        
                        $parameter5valueentry1value= $file->createElement("value", "1");
                        $newParameter5valueentry1value = $parameter5valueentry1->appendChild($parameter5valueentry1value);
                            

                    $parameter5valueentry2= $file->createElement("valueentry");
                    $newParameter5valueentry2 = $parameter5valuelist->appendChild($parameter5valueentry2);
                        
                        $parameter5valueentry2name= $file->createElement("name", "Center");
                        $newParameter5valueentry2name = $parameter5valueentry2->appendChild($parameter5valueentry2name);
                        
                        $parameter5valueentry2value= $file->createElement("value", "2");
                        $newParameter5valueentry2value = $parameter5valueentry2->appendChild($parameter5valueentry2value);
                    
                    $parameter5valueentry3 = $file->createElement("valueentry");
                    $newParameter5valueentry3 = $parameter5valuelist->appendChild($parameter5valueentry3);
                    
                        $parameter5valueentry3name= $file->createElement("name", "Right");
                        $newParameter5valueentry3name = $parameter5valueentry3->appendChild($parameter5valueentry3name);
                        
                        $parameter5valueentry3value= $file->createElement("value", "3");
                        $newParameter5valueentry3value = $parameter5valueentry3->appendChild($parameter5valueentry3value);
                    
                $parameter5value = $file->createElement("value", $param->getAlignment());
                $newParameter5value = $parameter5->appendChild($parameter5value);
          
           
            
            //Some Settings: 0Size, 1tracking, 2lead, 3aspect, 4line width, 5linesoft, 6text opacity, 7Horizontal size, 8Vertical size,     9Horizontal offset, 10Vertical offset, 11Back Soft, 12Back Opacity


             $groupParam1 = array (
                'TextSize' => array('id' => 'size',
                                    'name' => 'Size',
                                    'valuemin' => '0',
                                    'valuemax' => '200',
                                    'value' => $param->getTextSize()
                              ),
                'Tracking' => array('id' => 'track',
                                    'name' => 'Tracking',
                                    'valuemin' => '0',
                                    'valuemax' => '100',
                                    'value' => $param->getTracking()
                              ),
                'Leading' => array('id' => 'lead',
                                    'name' => 'Leading',
                                    'valuemin' => '-100',
                                    'valuemax' => '100',
                                    'value' => $param->getTextLeading()
                              ),
                'Aspect' => array('id' => 'aspect',
                                    'name' => 'Aspect',
                                    'valuemin' => '0',
                                    'valuemax' => '4',
                                    'value' => $param->getAspect()
                              ),
                'Line Width' => array('id' => 'linewidth',
                                    'name' => 'Line Width',
                                    'valuemin' => '0',
                                    'valuemax' => '200',
                                    'value' => $param->getLineWidth()
                              ),

                'Line Softness' => array('id' => 'linesoft',
                                    'name' => 'Line Softness',
                                    'valuemin' => '0',
                                    'valuemax' => '100',
                                    'value' => $param->getLineSoftness()
                              ),
                'Text Opacity' => array('id' => 'textopacity',
                                    'name' => 'Text Opacity',
                                    'valuemin' => '0',
                                    'valuemax' => '100',
                                    'value' => $param->getTextOpacity()
                              ),

                );


            $this->createElements($groupParam1, $file, $effect);

        
            //Center
        

            if ($param->getSameLine() == true) {
                $centerX = $param->getCenterXtwo();
                $centerY = $param->getCenterYtwo();
            } else {

                if (preg_match_all ('/\n/',$sub->getText()) == 0) {
                    $centerX = $param->getCenterXone();
                    $centerY = $param->getCenterYone();
                } else {
                    $centerX = $param->getCenterXtwo();
                    $centerY = $param->getCenterYtwo();
                }

            }



            $parameter6 = $file->createElement("parameter");
            $newParameter6 = $effect->appendChild($parameter6);

                $parameter6id = $file->createElement("parameterid", "center");
                $newParameter6id = $parameter6->appendChild($parameter6id);
                
                $parameter6name = $file->createElement("name", "Center");
                $newParameter6name = $parameter6->appendChild($parameter6name);
                
                $parameter6value= $file->createElement("value");
                $newParameter6value = $parameter6->appendChild($parameter6value);
                
                    $parameter6valuehoriz= $file->createElement("horiz", round(($centerX/$resWidth),2));
                    $newParameter6valuehoriz = $parameter6value->appendChild($parameter6valuehoriz);
                        
                    $parameter6valuevert= $file->createElement("vert", round(($centerY/$resHeight),2));
                    $newParameter6valuevert = $parameter6value->appendChild($parameter6valuevert);
            
    

            //Text Color
                    
            $parameter7 = $file->createElement("parameter");
            $newParameter7 = $effect->appendChild($parameter7);

                $parameter7id = $file->createElement("parameterid", "textcolor");
                $newParameter7id = $parameter7->appendChild($parameter7id);
                
                $parameter7name = $file->createElement("name", "Text Color");
                $newParameter7name = $parameter7->appendChild($parameter7name);
                
                $parameter7value= $file->createElement("value");
                $newParameter7value = $parameter7->appendChild($parameter7value);
                
                    $parameter7valuealpha = $file->createElement("alpha", $param->getColorAlpha());
                    $newParameter7valuealpha = $parameter7value->appendChild($parameter7valuealpha);
                        
                    $parameter7valuered = $file->createElement("red", $param->getTextColor()[0]);
                    $newParameter7valuered = $parameter7value->appendChild($parameter7valuered);
                    
                    $parameter7valuegreen = $file->createElement("green", $param->getTextColor()[1]);
                    $newParameter7valuegreen = $parameter7value->appendChild($parameter7valuegreen);
                        
                    $parameter7valueblue = $file->createElement("blue", $param->getTextColor()[2]);
                    $newParameter7valueblue = $parameter7value->appendChild($parameter7valueblue);

            
            //Super Text
            
            $parameter8 = $file->createElement("parameter");
            $newParameter8 = $effect->appendChild($parameter8);
            
                $parameter8id = $file->createElement("parameterid", "supertext");
                $newParameter8id = $parameter8->appendChild($parameter8id);
                
                $parameter8name = $file->createElement("name", "Text Graphic");
                $newParameter8name = $parameter8->appendChild($parameter8name); 
            


            //Line Color
            
            $parameter9 = $file->createElement("parameter");
            $newParameter9 = $effect->appendChild($parameter9);
                    
                $parameter9id = $file->createElement("parameterid", "linecolor");
                $newParameter9id = $parameter9->appendChild($parameter9id);
                
                $parameter9name = $file->createElement("name", "Line Color");
                $newParameter9name = $parameter9->appendChild($parameter9name);
                
                $parameter9value= $file->createElement("value");
                $newParameter9value = $parameter9->appendChild($parameter9value);
                
                    $parameter9valuealpha = $file->createElement("alpha", $param->getOutColorAlpha());
                    $newParameter9valuealpha = $parameter9value->appendChild($parameter9valuealpha);
                        
                    $parameter9valuered = $file->createElement("red", $param->getOutColor()[0]);
                    $newParameter9valuered = $parameter9value->appendChild($parameter9valuered);
                    
                    $parameter9valuegreen = $file->createElement("green", $param->getOutColor()[1]);
                    $newParameter9valuegreen = $parameter9value->appendChild($parameter9valuegreen);
                        
                    $parameter9valueblue = $file->createElement("blue", $param->getOutColor()[2]);
                    $newParameter9valueblue = $parameter9value->appendChild($parameter9valueblue);
            
            //Line Graphic
            
            $parameter10 = $file->createElement("parameter");
            $newParameter10 = $effect->appendChild($parameter10);
            
                $parameter10id = $file->createElement("parameterid", "superline");
                $newParameter10id = $parameter10->appendChild($parameter10id);
                
                $parameter10name = $file->createElement("name", "Line Graphic");
                $newParameter10name = $parameter10->appendChild($parameter10name);  

                
            //Background Settings
                
            $parameter11 = $file->createElement("parameter");
            $newParameter11 = $effect->appendChild($parameter11);
            
                $parameter11id = $file->createElement("parameterid", "part2");
                $newParameter11id = $parameter11->appendChild($parameter11id);
                
                $parameter11name = $file->createElement("name", "Background Settings");
                $newParameter11name = $parameter11->appendChild($parameter11name);  
                
                $parameter11value = $file->createElement("value");
                $newParameter11value = $parameter11->appendChild($parameter11value);    
            
            
            //ELEMENTS 7Horizontal size, 8Vertical size, 9Horizontal offset, 10Vertical offset, 11Back Soft, 12Back Opacity
            
            
             $groupParam2 = array (
                'xScale' => array('id' => 'xscale',
                                    'name' => 'Horizontal Size',
                                    'valuemin' => '0',
                                    'valuemax' => '200',
                                    'value' => $param->getXScale()
                              ),
                'yScale' => array('id' => 'yscale',
                                    'name' => 'Vertical Size',
                                    'valuemin' => '0',
                                    'valuemax' => '200',
                                    'value' => $param->getYScale()
                              ),
                'xOffset' => array('id' => 'xoffset',
                                    'name' => 'Horizontal Offset',
                                    'valuemin' => '-100',
                                    'valuemax' => '100',
                                    'value' => $param->getXOffset(),
                               ),
                'yOffset' => array('id' => 'yoffset',
                                    'name' => 'Vertical Offset',
                                    'valuemin' => '-100',
                                    'valuemax' => '100',
                                    'value' => $param->getYOffset()
                              ),
                'Back Soft' => array('id' => 'backsoft',
                                    'name' => 'Back Soft',
                                    'valuemin' => '0',
                                    'valuemax' => '100',
                                    'value' => $param->getBackSoft()
                              ),
                'Back Opacity' => array('id' => 'backopacity',
                                    'name' => 'Back Opacity',
                                    'valuemin' => '0',
                                    'valuemax' => '100',
                                    'value' => $param->getBackOpacity()
                              )

                );

                $this->createElements($groupParam2, $file, $effect);

            //Back Color
            
            $parameter12 = $file->createElement("parameter");
            $newParameter12 = $effect->appendChild($parameter12);
                    
                $parameter12id = $file->createElement("parameterid", "backcolor");
                $newParameter12id = $parameter12->appendChild($parameter12id);
                
                $parameter12name = $file->createElement("name", "Back Color");
                $newParameter12name = $parameter12->appendChild($parameter12name);
                
                $parameter12value= $file->createElement("value");
                $newParameter12value = $parameter12->appendChild($parameter12value);
                
                    $parameter12valuealpha = $file->createElement("alpha", $param->getBackColorAlpha());
                    $newParameter12valuealpha = $parameter12value->appendChild($parameter12valuealpha);
                        
                    $parameter12valuered = $file->createElement("red", $param->getBackColor()[0]);
                    $newParameter12valuered = $parameter12value->appendChild($parameter12valuered);
                    
                    $parameter12valuegreen = $file->createElement("green", $param->getBackColor()[1]);
                    $newParameter12valuegreen = $parameter12value->appendChild($parameter12valuegreen);
                        
                    $parameter12valueblue = $file->createElement("blue", $param->getBackColor()[2]);
                    $newParameter12valueblue = $parameter12value->appendChild($parameter12valueblue);

            
            //Back Graphic
            
            $parameter13 = $file->createElement("parameter");
            $newParameter13 = $effect->appendChild($parameter13);
            
                $parameter13id = $file->createElement("parameterid", "superback");
                $newParameter13id = $parameter13->appendChild($parameter13id);
                
                $parameter13name = $file->createElement("name", "Back Graphic");
                $newParameter13name = $parameter13->appendChild($parameter13name);  
            
            //Crop
                
            $parameter14 = $file->createElement("parameter");
            $newParameter14 = $effect->appendChild($parameter14);

                $parameter14id = $file->createElement("parameterid", "crop");
                $newParameter14id = $parameter14->appendChild($parameter14id);
                
                $parameter14name = $file->createElement("name", "Crop");
                $newParameter14name = $parameter14->appendChild($parameter14name);
                
                $parameter14value = $file->createElement("value", $param->getCrop());
                $newParameter14value = $parameter14->appendChild($parameter14value);

            //Auto Kerning

            $parameter15 = $file->createElement("parameter");
            $newParameter15 = $effect->appendChild($parameter15);

                $parameter15id = $file->createElement("parameterid", "autokern");
                $newParameter15id = $parameter15->appendChild($parameter15id); 
                
                $parameter15name = $file->createElement("name", "Auto Kerning");
                $newParameter15name = $parameter15->appendChild($parameter15name);
                
                $parameter15value = $file->createElement("value", $param->getKern());
                $newParameter15value = $parameter15->appendChild($parameter15value);

            //Sourcetrack
            
            $sourcetrack = $file->createElement("sourcetrack");
            $newSourcetrack = $generatoritem->appendChild($sourcetrack);

                $mediatype = $file->createElement("mediatype", "video");
                $newMediatype  = $sourcetrack->appendChild($mediatype);
            
            //Uuid
            /*
            $itemhistory = $file->createElement("itemhistory");
            $newItemhistory = $generatoritem->appendChild($itemhistory);

                $uuid = $file->createElement("uuid", $uuidXml);
                $newUuid  = $itemhistory->appendChild($uuid);
    
            */
    }

         
        $savePath = __DIR__.'/../../../../web/files/Subtitle_Converter_New.xml';

        $file -> save($savePath, LIBXML_NOEMPTYTAG);
    

        $arxiu = basename($savePath);

        header('Content-Type: text/xml');
        //
        header('Content-Disposition: attachment; filename='.$arxiu);
        header('Content-Transfer-Encoding: binary');
        header('Content-Length: '.filesize($savePath));
        readfile($savePath);
        
    }


    //OVERRIDE
    public function setFrameRate($framRate=null){

        if($framRate === null) {
            $this->frameRate = $this->xml->getElementsByTagName('timecode')->item(0)->getElementsByTagName('timebase')->item(0)->nodeValue;
        } else {
            $this->frameRate = $frameRate;
        }
    }

    public function setCharset($charset=null){

        if($charset === null) {
            $this->charset = $this->xml->encoding;
        } else {
            $this->charset = $charset;
        }
    }


    public function getVersion() {
        return $this->version;
    }


    public function setVersion($version=null) {

        if($version === null) {
            $this->version = $this->xml->getElementsByTagName('xmeml')->item(0)->getAttribute('version');

        } else {
            $this->version = $version;
        }
    }


    protected function checkStyleText($param, $italic) {

        if($param->getTextStyle() == 0) {
            if ($italic == true) {
                $style = 3;
            }
            else{
                $style = 1;
            }
        }
        else {
            $style = $param->getTextStyle();
        }  
        return $style;

    }



    protected function createElements($params, $file, $effect) {
    
        foreach ($params as $param)
        {
        
        $parameter = $file->createElement("parameter");
        $newParameter = $effect->appendChild($parameter);

            $parameterid = $file->createElement("parameterid",$param['id']);
            $newParameterid = $parameter->appendChild($parameterid);
            
            $parametername = $file->createElement("name", $param['name']);
            $newParametername = $parameter->appendChild($parametername);
            
            $parametervaluemin = $file->createElement("valuemin", $param['valuemin']);
            $newParametervaluemin = $parameter->appendChild($parametervaluemin);
            
            $parametervaluemax = $file->createElement("valuemax", $param['valuemax']);
            $newParametervaluemax = $parameter->appendChild($parametervaluemax);
            
            $parametervalue = $file->createElement("value",$param['value']);
            $newParametervalue = $parameter->appendChild($parametervalue);
            
        }
    }       

}