<?php
namespace AppBundle\Model\SubsFormat;

use AppBundle\Model\SubsFormat\Format;


abstract class FormatFCPX extends Format
{

    protected $xml;

    // Video Parameters
    protected $version;
    protected $widthRes;
    protected $heightRes;
    protected $resolution;
    protected $seqName;
    protected $seqDuration;
    protected $videoFormat;
    protected $uuid;

    protected $videoParam;


    public function __construct($file=null) {
        parent::__construct($file);
    }

    public function loadFile(){
        // Open File
        $root = simplexml_load_file($this->file);
        $this->xml = new \DomDocument();
        $this->xml->loadXML($root->asXML());
    }

    

    public function getParamList()
    {
        $projectTag = $this->xml->getElementsByTagName('project');
        $formatTag = $this->xml->getElementsByTagName('format');
        $sequenceTag = $this->xml->getElementsByTagName('sequence');


        $this->seqName = $projectTag->item(0)->getAttribute('name');

        $this->widthRes = $formatTag->item(0)->getAttribute('width');
        $this->heightRes = $formatTag->item(0)->getAttribute('height');
        $this->resolution =  $this->widthRes.'x'.$this->heightRes;

        $this->videoFormat = $formatTag->item(0)->getAttribute('name');
        
        $this->seqDuration = $this->convertTcIn($sequenceTag->item(0)->getAttribute('duration'), $this->frameRate);
        $this->uuid = $projectTag->item(0)->getAttribute('uid');


        $this->videoParam = array(
            'seqName' => $this->seqName,
            'seqDuration' => $this->seqDuration,
            'resolution' => $this->resolution,
            'videoFormat' => $this->videoFormat,
            'uuid'=> $this->uuid,
        ); 

        return $this->videoParam;
    }

    //OVERRIDE
    public function setFrameRate($framRate=null){
        $this->frameRate = $this->frameRateConv($this->xml->getElementsByTagName('format')->item(0)->getAttribute('frameDuration'));
    }


    public function getVersion($version=null) {
        return $this->version;
    }


    public function setVersion() {
        $this->version = $this->xml->getElementsByTagName('fcpxml')->item(0)->getAttribute('version');
    }



    protected function substringTcString($string) {

        $string = substr($string, 0, -1);
        if (strpos($string, '/') === false) {
            $result[] = $string;
            $result[] = 1;
        } else {
            $string = explode ("/", $string);
            $result[] = $string[0];
            $result[] = $string[1];
        }
        return $result;

    }

    protected  function frameRateConv($string) {

        $numbers = $this->substringTcString($string);
        $frameRate = round($numbers[1]/$numbers[0], 2);
        return $frameRate;
    }


    protected  function convertTcIn($offset, $frameRate) {

        $offset = $this->substringTcString($offset);
        $seconds = $offset[0]/$offset[1];
        $tc  = $this->convertNumberToTc($seconds, $frameRate);
        return $tc;

    }  

    protected  function convertTcOut($offset, $duration, $frameRate) {

        $offset = $this->substringTcString($offset);
        $duration = $this->substringTcString($duration);
        $offsetTotal = $offset[0]/$offset[1];
        $durationTotal = $duration[0]/$duration[1];
        $seconds = $offsetTotal + $durationTotal;
        $tc  = $this->convertNumberToTc($seconds, $frameRate);
        return $tc;
    }  

    protected  function convertNumberToTc($seconds, $frameRate) {

        $secondsTotal = floor($seconds);
        $frames = round(($seconds-intval($seconds)) * $frameRate);
        $hours = floor($secondsTotal / 3600);
        $mins = floor($secondsTotal / 60 % 60);
        $secs = floor($secondsTotal % 60);

        $tcString = str_pad($hours, 2, "0", STR_PAD_LEFT).":".str_pad($mins, 2, "0", STR_PAD_LEFT).":".str_pad($secs, 2, "0", STR_PAD_LEFT).":".str_pad($frames, 2, "0", STR_PAD_LEFT);

        return $tcString;
    }


}