<?php
namespace AppBundle\Model\SubsFormat;

use AppBundle\Model\SubsFormat\Format;
use AppBundle\Model\SubsFormat\Subtitle as Subtitle;



class FormatSRT extends Format
{

    protected $fileLines;

    public function __construct($file=null) {
        parent::__construct($file);
        if ($file !== null) $this->loadFile($this->file);
    }
   
    public function loadFile(){

        $this->fileLines = file($this->file);   
    }


    public function getSubtitlesList()
    {

        define('LINE_ID', 0);
        define('LINE_TIME',      1);
        define('LINE_TEXT',      2);
        define('LINE_BLANK',     3);

        $state   = LINE_ID;
        $subNum  = 0;
        $subText = '';
        $subTime = '';

        $totalLines = count($this->fileLines);

        foreach($this->fileLines as $key => $line) {
            switch($state) {
                case LINE_ID:
                    $subNum = trim($line);
                    $state  = LINE_TIME;
                    break;

                case LINE_TIME:
                    $subTime = trim($line);
                    $state   = LINE_TEXT;
                    break;

                case LINE_TEXT:
 
                    if ((trim($line) == '') || ($key == $totalLines-1 && !(trim($line) == ''))) {

                        if ($key ==  $totalLines-1 && !(trim($line) == '')){
                            $subText .= $line;
                        }

                        $id = $subNum;

                        $tc = explode ("-->",$subTime);
                        $tcIn = $this->milisegToFrames(trim($tc[0]), $this->frameRate);
                        $tcOut = $this->milisegToFrames(trim($tc[1]), $this->frameRate);

                        $italic = false;

                        $cadena1 = '<i>';
                        $check1 = stripos($subText, $cadena1);
                        $cadena2 = '</i>';
                        $check2 = stripos($subText, $cadena2);

                        if ($check1 !== false || $check2 !== false  ) 
                        {
                            $italic = true;
                        } 

                        if ($this->charset != 'utf-8') {
                            $text = iconv($this->charset, 'utf-8//IGNORE', trim(strip_tags($subText)));
                        } else {
                            $text = trim(strip_tags($subText));
                        }

                        $this->subtitlesList[] = new Subtitle($id, $tcIn, $tcOut, $text, $italic);

                        $subText = '';
                        $state = LINE_ID;
                    } else {
                        $subText .= $line;
                    }
                    break;
            }
        }

        return $this->subtitlesList;  
    }


     protected function framesToMiliseg($tc, $frameRate) {
        $frames = substr($tc, -2);
        $miliseg = round((1000/$frameRate) * $frames);
        $miliseg = str_pad($miliseg, 3, "0", STR_PAD_LEFT);
        $tcInitial = substr($tc,0, 8);
        $tcFinal = $tcInitial.",".$miliseg;
        return $tcFinal;
    }

    protected function milisegToFrames($tc, $frameRate) {
        $miliseg = substr($tc, -3);
        $frames = round($miliseg * ($frameRate/1000));
        if ($frames == $frameRate) $frames = $frameRate - 1;

        $frames = str_pad($frames, 2, "0", STR_PAD_LEFT);
        $tcInitial = substr($tc,0, 8);
        $tcFinal = $tcInitial.":".$frames;
        return $tcFinal;
    }

   
    public function createNewFile($subtitlesList=null, $OriginalFrameRate=null, $targetFrameRate=null) 
    {
       
        if (!($targetFrameRate == 'thesame' || $targetFrameRate == $OriginalFrameRate)) {
            $frameRate = $targetFrameRate;

            foreach ($subtitlesList as $sub) {
                $newTcIn = $this->changeFrameRate($sub->getTcIn(), $OriginalFrameRate,  $targetFrameRate);
                $newTcOut = $this->changeFrameRate($sub->getTcOut(), $OriginalFrameRate,  $targetFrameRate);
                $sub->setTcIn($newTcIn);
                $sub->setTcOut($newTcOut);
            }
        } else {
            $frameRate = $OriginalFrameRate;
        }


        $filename = 'Subtitle_Converter_New.srt';
        $file = fopen($filename,"w");

        foreach ($subtitlesList as $sub) {
            fwrite($file, $sub->getId().PHP_EOL);
            fwrite($file, $this->framesToMiliseg($sub->getTcIn(), $frameRate).' --> '.$this->framesToMiliseg($sub->getTcOut(), $frameRate).PHP_EOL);

            if ($sub->getItalic() == true)
            {
                fwrite($file, '<i>'.$sub->getText().'</i>'.PHP_EOL);
            } else {
                fwrite($file, $sub->getText().PHP_EOL);
            }
            fwrite($file, PHP_EOL);
        }
        fclose($file);
        return $filename;
    }
}
